#
# spec file for package golang-github-prometheus-alertmanager
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           golang-github-prometheus-alertmanager
Version:        0.23.0
Release:        150100.4.13.2
Summary:        Prometheus Alertmanager
License:        Apache-2.0
URL:            https://prometheus.io/
Source:         alertmanager-%{version}.tar.gz
# generated after applying 0002-Update-prometheus-client-to-version-1.11.1.patch
Source1:        vendor.tar.gz
Source2:        prometheus-alertmanager.service
Source3:        alertmanager.yml
# Lifted from Debian's alertmanager package
Patch1:         0001-Default-settings.patch
# This patch has been applied before generating vendor tarball
Patch2:         0002-Update-prometheus-client-to-version-1.11.1.patch
# This patch has been applied before generating vendor tarball
Patch3:         0003-Update-prometheus-exporter-toolkit-to-0.7.3.patch
BuildRequires:  fdupes
BuildRequires:  golang-github-prometheus-promu >= 0.12.0
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.16
Requires(pre):  group(prometheus)
Requires(pre):  user(prometheus)
Provides:       prometheus-alertmanager = %{version}
ExcludeArch:    s390
%{?systemd_ordering}

%{go_nostrip}

%description
The Alertmanager handles alerts sent by client applications such as the
Prometheus server. It takes care of deduplicating, grouping, and routing
them to the correct receiver integration such as email, PagerDuty, or
OpsGenie. It also takes care of silencing and inhibition of alerts.

%prep
%autosetup -a1 -p1 -n alertmanager-%{version}

%build
%goprep github.com/prometheus/alertmanager
export BUILDFLAGS="-v -p 4 -x -buildmode=pie -mod=vendor"
GOPATH=%{_builddir}/go promu build

%install
%goinstall
install -D -m0755 %{_builddir}/alertmanager-%{version}/alertmanager %{buildroot}/%{_bindir}/alertmanager
install -D -m0755 %{_builddir}/alertmanager-%{version}/amtool %{buildroot}/%{_bindir}/amtool
mv %{buildroot}%{_bindir}/alertmanager %{buildroot}%{_bindir}/prometheus-alertmanager
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/prometheus-alertmanager.service
install -Dd -m 0755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcprometheus-alertmanager
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/prometheus/alertmanager.yml
install -Dd -m 0755 %{buildroot}%{_sysconfdir}/prometheus/alertmanager_templates
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus
install -Dd -m 0750 %{buildroot}%{_localstatedir}/lib/prometheus/alertmanager
%fdupes %{buildroot}/%{_prefix}

%pre
%service_add_pre prometheus-alertmanager.service

%post
%service_add_post prometheus-alertmanager.service

%preun
%service_del_preun prometheus-alertmanager.service

%postun
%service_del_postun prometheus-alertmanager.service

%files
%doc README.md
%license LICENSE
%{_bindir}/prometheus-alertmanager
%{_bindir}/amtool
%{_unitdir}/prometheus-alertmanager.service
%{_sbindir}/rcprometheus-alertmanager
%dir %attr(0700, prometheus, prometheus) %{_localstatedir}/lib/prometheus
%dir %attr(0700, prometheus, prometheus) %{_localstatedir}/lib/prometheus/alertmanager
%dir %{_sysconfdir}/prometheus
%dir %{_sysconfdir}/prometheus/alertmanager_templates
%config(noreplace) %{_sysconfdir}/prometheus/alertmanager.yml

%changelog
* Fri Mar 10 2023 witold.bedyk@suse.com
- Prevent authentication bypass via cache poisoning
  (bsc#1208051, CVE-2022-46146)
- Add 0003-Update-prometheus-exporter-toolkit-to-0.7.3.patch
* Tue Jul 19 2022 witold.bedyk@suse.com
- Do not include sources (bsc#1200725)
* Fri Apr  8 2022 witold.bedyk@suse.com
- Update required Go version to 1.16
* Thu Mar 10 2022 witold.bedyk@suse.com
- Update vendor tarball with prometheus/client_golang 1.11.1
  (bsc#1196338, jsc#SLE-24077)
  + Added 0002-Update-prometheus-client-to-version-1.11.1.patch
- Use %%autosetup macro
* Thu Mar  3 2022 ecsos@opensuse.org
- Update to version 0.23.0:
  * Release 0.23.0
  * Release 0.23.0-rc.0
  * amtool: Detect version drift and warn users (#2672)
  * Add ability to skip TLS verification for amtool (#2663)
  * Fix empty isEqual in amtool. (#2668)
  * Fix main tests (#2670)
  * cli: add new template render command (#2538)
  * OpsGenie: refer to alert instead of incident (#2609)
  * Docs: target_match and source_match are DEPRECATED (#2665)
  * Fix test not waiting for cluster member to be ready
- Add go_modules to _service.
* Mon Sep 20 2021 jsegitz@suse.com
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * prometheus-alertmanager.service
* Mon Nov 30 2020 witold.bedyk@suse.com
- Exclude s390 architecture
* Mon Nov  9 2020 stefano.torresi@suse.com
- Update packaging
  * Remove systemd and shadow hard requirements
  * use the system user provided by the system-user-prometheus subpackge
  * add 'prometheus-alertmanager' package alias
* Fri Oct 30 2020 witold.bedyk@suse.com
- Fix building amtool (bsc#1176943)
* Fri Aug 28 2020 elimat@opensuse.org
- Fix permissions for /var/lib/prometheus to match
  golang-github-prometheus-prometheus package. Otherwise the install check will
  fail.
* Sat Jul 18 2020 elimat@opensuse.org
- Update to 0.21.0
  + Changes:
  * [HipChat] Remove HipChat integration as it is end-of-life. #2282
  * [amtool] Remove default assignment of environment variables. #2161
  * [PagerDuty] Enforce 512KB event size limit. #2225
  + Enhancements:
  * [amtool] Add cluster command to show cluster and peer statuses. #2256
  * Add redirection from / to the routes prefix when it isn't empty. #2235
  * [Webhook] Add max_alerts option to limit the number of alerts included in the payload. #2274
  * Improve logs for API v2, notifications and clustering. #2177 #2188 #2260 #2261 #2273
  + Bugfixes:
  * Fix child routes not inheriting their parent route's grouping when group_by: [...]. #2154
  * [UI] Fix the receiver selector in the Alerts page when the receiver name contains regular expression metacharacters such as +. #2090
  * Fix error message about start and end time validation. #2173
  * Fix a potential race condition in dispatcher. #2208
  * [API v2] Return an empty array of peers when the clustering is disabled. #2203
  * Fix the registration of alertmanager_dispatcher_aggregation_groups and alertmanager_dispatcher_alert_processing_duration_seconds metrics. #2200
  * Always retry notifications with back-off. #2290
- Run spec-cleaner
- Remove rpm group
- Update to build with go1.14 for Factory (Tumbleweed)
- Refresh example config from upstream
* Fri Aug  2 2019 jan.fajerski@suse.com
- Add network-online (Wants and After) dependency to systemd unit bsc#1143913
* Tue Apr 16 2019 jan.fajerski@suse.com
- Update to 0.16.2
  + Bug Fixes:
  * Redact notifier URL from logs to not leak secrets embedded in the URL
  * Allow sending of unauthenticated SMTP requests when smtp_auth_username is not supplied
* Fri Feb  8 2019 jan.fajerski@suse.com
- Update to 0.16.1:
  + Bug Fixes:
  * Do not populate cluster info if clustering is disabled in API v2
- Update to 0.16.0:
  + Deprecate API v1
  + Remove api/v1/alerts/groups GET endpoint
  + Revert Alertmanager working directory changes in Docker image back to /alertmanager
  + Using the recommended label syntax for maintainer in Dockerfile
  + Change alertmanager_notifications_total to count attempted notifications, not only successful ones (#1578)
  + Run as nobody inside container
  + Support w for weeks when creating silences, remove y for year
  + Features:
  * Introduce OpenAPI generated API v2
  * Lookup parts in strings using regexp.MatchString in templates
  * Support image/thumb url in attachment in Slack notifier
  * Support custom TLS certificates for the email notifier
  * Add support for images and links in the PagerDuty notification config
  * Add support for grouping by all labels
  * [amtool] Add timeout support to amtool commands
  * [amtool] Added config routes tools for vizualization and testing routes
  * [amtool] Support adding alerts using amtool
  + Enhancements:
  * Add support for --log.format
  * Add CORS support to API v2
  * Support HTML, URL title and custom sounds for Pushover
  * Update Alert compact view
  * Support adding custom fields to VictorOps notifications
  * Add help link in UI to Alertmanager documentation
  * Enforce HTTP or HTTPS URLs in Alertmanager config
  * Make OpsGenie API Key a templated string
  * Add name, value and SlackConfirmationField to action in Slack notifier
  * Show more alert information on silence form and silence view pages
  * Add cluster peers DNS refresh job
  + Bug Fixes:
  * Fix unmarshalling of secret URLs in config
  * Do not write groupbyall and groupby when marshaling config
  * Make a copy of firing alerts with EndsAt=0 when flushing
  * Respect regex matchers when recreating silences in UI
  * Change DefaultGlobalConfig to a function in Alertmanager configuration
  * Fix email template typo in alert-warning style
  * Fix silence redirect on silence creation UI page
  * Add missing callback_id parameter in Slack notifier
  * Throw error if no auth mechanism matches in email notifier
  * Use quoted-printable transfer encoding for the email notifier
  * Do not merge expired gossip messages
  * Fix "PLAIN" auth during notification via smtp-over-tls on port 465
  * [amtool] Support for assuming first label is alertname in silence add and query
  * [amtool] Support assuming first label is alertname in alert query with matchers
  * [amtool] Fix config path check in amtool
  * [amtool] Fix rfc3339 example texts
  * [amtool] Fixed issue with loading path of a default configs
- Update to 0.15.3
  + Bug Fixes:
  * Fix alert merging supporting both empty and set EndsAt property for firing alerts send by Prometheus
- Update to 0.15.2:
  + Enhancements:
  * [amtool] Add support for stdin to check-config
  * Log PagerDuty v1 response on BadRequest
  + Bug Fixes:
  * Correctly encode query strings in notifiers (#1516)
  * Add cache control headers to the API responses to avoid IE caching
  * Avoid listener blocking on unsubscribe
  * Fix a bunch of unhandled errors
  * Update PagerDuty API V2 to send full details on resolve
  * Validate URLs at config load time
  * Fix Settle() interval
  * Fix email to be green if only none firing
  * Handle errors in notify
  * Fix templating of hipchat room id
- Update to 0.15.1:
  + Bug Fixes:
  * Fix email template typo in alert-warning style
  * Fix regression in Pager Duty config
  * Catch templating errors in Wechat Notify
  * Fail when no private address can be found for cluster
  * Make sure we don't miss the first pushPull when joining cluster
  * Fix concurrent read and wirte group error in dispatch
- Update to 0.15.0:
  + [amtool] Update silence add and update flags
  + Replace deprecated InstrumentHandle
  + Validate Slack field config and only allow the necessary input
  + Remove legacy alert ingest endpoint
  + Move to memberlist as underlying gossip protocol including cluster flag changes from --mesh.xxx to --cluster.xxx
  + Move Alertmanager working directory in Docker image to /etc/alertmanager
  + The default group by is no labels.
  + Features:
  * [amtool] Filter alerts by receiver
  * Wait for mesh to settle before sending alerts
  * [amtool] Support basic auth in alertmanager url
  * Make HTTP clients used for integrations configurable
  + Enhancements:
  * Support receiving alerts with end time and zero start time
  * Sort dispatched alerts by job+instance
  * Support alert query filters active and unprocessed
  * [amtool] Expose alert query flags --active and --unprocessed
  * Add Slack actions to notifications
  + Bug Fixes:
  * Register nflog snapShotSize metric
  * Sort alerts in correct order before flushing to notifiers
  * Don't reset initial wait timer if flush is in-progress
  * Fix resolved alerts still inhibiting
  * Template wechat config fields
  * Notify resolved alerts properly
  * Fix parsing for label values with commas
  * Hide sensitive Wechat configuration
  * Prepopulate matchers when recreating a silence
  * Fix wechat panic
  * Allow empty matchers in silences/filtering
  * Properly configure HTTP client for Wechat integration
* Thu Mar 15 2018 jan.fajerski@suse.com
- fix config token in alermanager.yml hipchat_url -> hipchat_api_url
* Wed Mar 14 2018 jan.fajerski@suse.com
- spec: fix argument for %%fdupes
- Update to 0.14.0:
  + Enhancements:
  * Allow templating PagerDuty receiver severity
  * Include receiver name in failed notifications log messages
  * Add mesh metrics
  + Bug fixes:
  * Don't notify of resolved alerts if none were reported firing
  * Notify only when new firing alerts are added
  * Don't count alerts with EndTime in the future as resolved
* Thu Jan 25 2018 kkaempf@suse.com
- Update to 0.13.0
  See https://github.com/prometheus/alertmanager/releases
* Thu Jul 27 2017 tserong@suse.com
- Add BuildRequires: fdupes
* Thu May 25 2017 tserong@suse.com
- Initial version
- Adjust default settings
- Added:
  * 0001-Default-settings.patch
